@@ -3,8 +3,39 @@
 ## fxi.R
 ## 2019-08-17 fxi.secr uses C++ call
 ## 2022-02-13 'sp' now in suggests
+## 2024-09-09 allhistfxi NaN from cpp set to zero
+## 2024-09-21 fx functions renamed
 ###############################################################################
 
+fxi.contour <- function (
+        object, i = 1, sessnum = 1, border = 100, nx = 64,
+        levels = NULL, p = seq(0.1,0.9,0.1), plt = TRUE, add = FALSE,
+        fitmode = FALSE, plotmode = FALSE, fill = NULL,
+        output = c('list','sf','SPDF'), ncores = NULL, ...) {
+
+    .Deprecated("fxiContour", package="secr",
+                "fxi.contour has been renamed fxiContour",
+                old = as.character(sys.call(sys.parent()))[1L])
+    fxiContour(object, i, sessnum, border, nx, levels, p, plt = TRUE,
+               add, fitmode, plotmode, fill, output, ncores, ...)
+}
+
+fxi.mode <- function (object, i = 1, sessnum = 1, start = NULL, ncores = NULL, ...) {
+    .Deprecated("fxiMode", package="secr",
+                "fxi.mode has been renamed fxiMode",
+                old = as.character(sys.call(sys.parent()))[1L])
+    fxiMode (object, i, sessnum, start, ncores, ...)
+}
+
+fx.total <- function (object, sessnum = 1, mask = NULL, ncores = NULL, ...) {
+    .Deprecated("fxTotal", package="secr", 
+                "fx.total has been renamed fxTotal",
+                old = as.character(sys.call(sys.parent()))[1L])
+    fxTotal (object, sessnum, mask, ncores, ...)
+}
+
+
+
 fxi2SPDF <- function (x, ID, levels) {
   if (requireNamespace('sp')) {
     if (missing(ID))
@@ -50,7 +81,7 @@ fxi2sf <- function (x, ID, levels) {
 }
 ###############################################################################
 
-fxi.contour <- function (
+fxiContour <- function (
     object, i = 1, sessnum = 1, border = 100, nx = 64,
     levels = NULL, p = seq(0.1,0.9,0.1), plt = TRUE, add = FALSE, 
     fitmode = FALSE, plotmode = FALSE, fill = NULL, 
@@ -70,7 +101,7 @@ fxi.contour <- function (
   xlevels <- unique(tempmask$x)
   ylevels <- unique(tempmask$y)
   
-  fxi <- function (ni) {
+  fxilocal <- function (ni) {
     z <- allz[[ni]]
     if (is.null(levels)) {
       temp <- sort(z, decreasing = T)
@@ -97,7 +128,7 @@ fxi.contour <- function (
       cc <- data.frame(cc[c('x','y')])
       templines$mode <- data.frame(x=mean(cc$x), y=mean(cc$y))
       if (fitmode) {
-        templines$mode <- fxi.mode(object, sessnum = sessnum,
+        templines$mode <- fxiMode(object, sessnum = sessnum,
                                    start = templines$mode, i = ni)
       }
       if (plt) {
@@ -124,10 +155,10 @@ fxi.contour <- function (
     templines
   }
   
-  allz <- fxi.secr(object, i=i, sessnum = sessnum, X = tempmask, ncores = ncores)
+  allz <- fxi(object, i=i, sessnum = sessnum, X = tempmask, ncores = ncores)
   if (!is.list(allz))
     allz <- list(allz)
-  temp <- lapply(1:length(allz), fxi)
+  temp <- lapply(1:length(allz), fxilocal)
   
   if (output == 'sf') {
       temp <- fxi2sf(temp)
@@ -144,8 +175,8 @@ fxi.contour <- function (
 
 ###############################################################################
 
-fxi.mode <- function (object, i = 1, sessnum = 1, start = NULL, ncores = NULL, ...) {
-  if (length(i)>1) stop ("fxi.mode takes single i")
+fxiMode <- function (object, i = 1, sessnum = 1, start = NULL, ncores = NULL, ...) {
+  if (length(i)>1) stop ("fxiMode takes single i")
   if (secr::ms(object))
     session.capthist <- object$capthist[[sessnum]]
   else
@@ -160,9 +191,9 @@ fxi.mode <- function (object, i = 1, sessnum = 1, start = NULL, ncores = NULL, .
   if (is.character(i))
     i <- match(i, row.names(session.capthist))
   if (is.na(i) | (i<1) | (i>nrow(session.capthist)))
-    stop ("invalid i in fxi.secr")
+    stop ("invalid i in fxi")
   fn <- function(xy,i) {
-    -fxi.secr(object, i=i, sessnum = sessnum, X = matrix(xy, ncol=2), ncores = ncores)[[1]]
+    -fxi(object, i=i, sessnum = sessnum, X = matrix(xy, ncol=2), ncores = ncores)[[1]]
   }
   temp <- nlm(f = fn, p = start, i = i, typsize = start, ...)$estimate
   data.frame(x=temp[1], y=temp[2])
@@ -173,7 +204,7 @@ fxi.mode <- function (object, i = 1, sessnum = 1, start = NULL, ncores = NULL, .
 ## mask if specified should be for a single session
 ## ... passes newdata df to predict.secr
 
-fx.total <- function (object, sessnum = 1, mask = NULL, ncores = NULL, ...)
+fxTotal.secr <- function (object, sessnum = 1, mask = NULL, ncores = NULL, ...)
 {
   if (ms(object)) {
       n <- nrow(object$capthist[[sessnum]])
@@ -187,8 +218,8 @@ fx.total <- function (object, sessnum = 1, mask = NULL, ncores = NULL, ...)
       detectpar <- detectpar(object, ...)
       CH <- object$capthist
   }
-  fxi <- fxi.secr(object, sessnum = sessnum, X = mask, ncores = ncores)
-  fx <- do.call(cbind, fxi)
+  fxilocal <- fxi(object, sessnum = sessnum, X = mask, ncores = ncores)
+  fx <- do.call(cbind, fxilocal)
   fxt <- apply(fx, 1, sum)
   fxt <- fxt/getcellsize(mask)
   D <- predictDsurface(object, mask = mask)
@@ -229,6 +260,8 @@ allhistfxi <- function (m, realparval, haztemp, gkhk, pi.density, PIA, usge,
           as.matrix(usge),
           as.matrix (hx),                
           as.matrix (hi))
+        ## 2024-09-09 purge uncomputed values for robustness
+        temp[is.na(temp)] <- 0
         sump <- sump + sweep(temp, MARGIN=1, STATS = pmixn[x,], FUN = "*")
     }
     sump
@@ -273,7 +306,7 @@ allhistpolygonfxi <- function (detectfn, realparval, haztemp, hk, H, pi.density,
     sump
 }
 
-fxi.secr <- function (object, i = NULL, sessnum = 1, X = NULL, ncores = NULL) {
+fxi.secr <- function (object, i = NULL, sessnum = 1, X = NULL, ncores = NULL, ...) {
     
     ## temporary fix for lack of fastproximity code
     object$details$fastproximity <- FALSE   ## 2020-08-30
@@ -364,7 +397,7 @@ fxi.secr <- function (object, i = NULL, sessnum = 1, X = NULL, ncores = NULL) {
   #             levels(data$grp[[1]]), sessionlevels, parameter = 'noneuc')
   # 
   NE <- NULL
-  
+ 
   #---------------------------------------------------
   ## allow for scaling of detection
   Dtemp <- if (D.modelled) mean(D) else NA
